@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : PM
-Version : 1.0.0
+Version : 1.1.0
 Author  : Stefano Covino
-Date    : 22/08/2012
+Date    : 22/08/2013
 E-mail  : stefano.covino@brera.inaf.it
 URL:    : http://www.merate.mi.astro.it/utenti/covino
 
@@ -13,7 +13,7 @@ Usage   : to be imported
 Remarks :
 
 History : (22/08/2012) First version.
-
+        : (22/08/2013) Just offsets.
 """
 
 import numpy
@@ -27,7 +27,7 @@ def Classic ((az,alt),(c_AN,c_AE,c_NPAE,c_BNP,c_TF,c_AOFS,c_EOFS)):
     # TF: sagging of the tube
     # AOFS: azimuth zero point correction
     # EOFS: altitude zero point correction
-    naz = az + c_AN * numpy.sin(numpy.radians(az)) * numpy.tan(numpy.radians(alt)) - c_AE * numpy.cos(numpy.radians(az)) * numpy.tan(numpy.radians(alt)) + c_NPAE * numpy.tan(numpy.radians(alt)) - c_BNP / numpy.cos(numpy.radians(alt)) + c_AOFS
-    nalt = alt + c_AN * numpy.cos(numpy.radians(az)) + c_AE * numpy.sin(numpy.radians(az)) + c_TF * numpy.cos(numpy.radians(alt)) + c_EOFS
+    naz = c_AN * numpy.sin(numpy.radians(az)) * numpy.tan(numpy.radians(alt)) - c_AE * numpy.cos(numpy.radians(az)) * numpy.tan(numpy.radians(alt)) + c_NPAE * numpy.tan(numpy.radians(alt)) - c_BNP / numpy.cos(numpy.radians(alt)) + c_AOFS
+    nalt = c_AN * numpy.cos(numpy.radians(az)) + c_AE * numpy.sin(numpy.radians(az)) + c_TF * numpy.cos(numpy.radians(alt)) + c_EOFS
     return naz, nalt
 
