@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : PM
-Version : 1.0.0
+Version : 1.1.0
 Author  : Stefano Covino
-Date    : 23/08/2012
+Date    : 22/08/2013
 E-mail  : stefano.covino@brera.inaf.it
 URL:    : http://www.merate.mi.astro.it/utenti/covino
 
@@ -13,7 +13,7 @@ Usage   : to be imported
 Remarks :
 
 History : (23/08/2012) First version.
-
+        : (22/08/2013) Improvement.
 """
 
 
@@ -23,6 +23,6 @@ from SRP.SRPMath.FastAngularDistance import FastAngularDistance
 
 
 def minClassic ((c_AN,c_AE,c_NPAE,c_BNP,c_TF,c_AOFS,c_EOFS),taz,talt,oaz,oalt):
-    caz, calt = Classic((oaz,oalt),(c_AN,c_AE,c_NPAE,c_BNP,c_TF,c_AOFS,c_EOFS))
-    return FastAngularDistance(taz,talt,caz,calt).sum()
+    caz, calt = Classic((taz,talt),(c_AN,c_AE,c_NPAE,c_BNP,c_TF,c_AOFS,c_EOFS))
+    return FastAngularDistance(oaz,oalt,caz,calt).sum()
 
