@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : PM
-Version : 1.0.0
+Version : 1.1.0
 Author  : Stefano Covino
-Date    : 23/08/2012
+Date    : 22/08/2013
 E-mail  : stefano.covino@brera.inaf.it
 URL:    : http://www.merate.mi.astro.it/utenti/covino
 
@@ -13,7 +13,7 @@ Usage   : to be imported
 Remarks :
 
 History : (23/08/2012) First version.
-
+        : (22/08/2013) Improvement.
 """
 
 
@@ -22,5 +22,5 @@ from SRP.SRPMath.FastAngularDistance import FastAngularDistance
 
 
 def minSimple ((s_AOFS,s_EOFS),taz,talt,oaz,oalt):
-    caz, calt = Simple((oaz,oalt),(s_AOFS,s_EOFS))
-    return FastAngularDistance(taz,talt,caz,calt).sum()
+    caz, calt = Simple((taz,talt),(s_AOFS,s_EOFS))
+    return FastAngularDistance(oaz,oalt,caz,calt).sum()
