@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : REM
-Version : 1.0.36
+Version : 1.0.40
 Author  : Stefano Covino
-Date    : 07/02/2014
+Date    : 06/08/2014
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -45,9 +45,13 @@ History : (16/12/2011) First version.
         : (07/01/2014) V. 1.5.08b.
         : (09/01/2014) V. 1.5.0b9.
         : (07/02/2014) V. 1.5.0.
+        : (25/07/2014) V. 1.5.1b1.
+        : (28/07/2014) V. 1.5.1b2.
+        : (05/08/2014) V. 1.5.1b3.
+        : (06/08/2014) V. 1.5.1.
 """
 
-__version__ = '1.5.0'
+__version__ = '1.5.1'
 
 
 
@@ -61,6 +65,13 @@ ROSSPixSize     = 0.59
 ROS2PixSize     = 0.59
 
 
+# REM center pixels
+REMIRXCenter    =   256
+REMIRYCenter    =   256
+ROSS2XCenter    =   512
+ROSS2YCenter    =   512
+
+
 # Constants
 REMIR   =   'REMIR'
 ROSS    =   'REM-ROSS'
